@@ -202,7 +202,7 @@ void replace_col(matrix *M, int col_to_set, vector *v);
 
 vector *extract_col(matrix *M, int col_to_get, vector *v);
 
-void Cpred(double *cum,int *nx,int *px,double *xval,int *nxval,double *pred); 
+void Cpred(double *cum,int *nx,int *px,double *xval,int *nxval,double *pred,int *tminus); 
 
 void sindex(int *index, double *jump, double *eval, int *njump, int *neval,int *strict);
 
@@ -237,8 +237,9 @@ void itfitsemi(double *times,int *Ntimes,double *x,int *delta,int *cause,double
 	       double *timepow,int *clusters,int *antclust,double *timepowtest,int *silent,double *convc,
 	       double *weight,double *entry,double *trunkp,int *estimator,int *fixgamma ,int *stratum,
                int *ordertime,int *robust,double *ssf,double *KMtimes,
-	       double *gamscore,double *Dscore);
+	       double *gamscore,double *Dscore,int *monotone);
 
+void bubble_sort(double *val,int *list,int n); 
 
 void LevenbergMarquardt(matrix *S,matrix *SI,vector *U,vector *delta,double *lm,double *step); 
  
@@ -256,3 +257,14 @@ void readXZt(int *antpers,int *nx,int *px,double *designX,int *pg,double *design
 void readXZtsimple(int *antpers,int *nx,int *px,double *designX,int *pg,double *designG,
 		double *start,double *stop,int *status,int pers,matrix *X,
 	       	matrix *Z,double time, int s, int *id); 
+
+void resmeansemi(double *times,int *Ntimes,double *x,int *delta,int *cause,
+	       double *KMc,double *z,int *antpers,int *px,int *Nit,
+	       double *score,double *hess,double *est,double *var,int *sim,
+	       int *antsim,int *rani,double *test,double *testOBS,double *Ut,
+	       double *simUt,int *weighted,double *gamma,double *vargamma,int *semi,
+	       double *zsem,int *pg,int *trans,double *gamma2,int *CA,
+	       int *line,int *detail,double *biid,double *gamiid,int *resample,
+	       double *timepow,int *clusters,int *antclust,double *timepowtest,int *silent,double *convc,double *tau,
+	       int *funcrestrict,int *causeS, double *weights,double *KMtimes); 
+
